/*
 * COPYRIGHT LICENSE: This information contains sample code provided in source code form. You may copy, modify, and distribute
 * these sample programs in any form without payment to IBM® for the purposes of developing, using, marketing or distributing
 * application programs conforming to the application programming interface for the operating platform for which the sample code is written.
 * Notwithstanding anything to the contrary, IBM PROVIDES THE SAMPLE SOURCE CODE ON AN "AS IS" BASIS AND IBM DISCLAIMS ALL WARRANTIES,
 * EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, ANY IMPLIED WARRANTIES OR CONDITIONS OF MERCHANTABILITY, SATISFACTORY QUALITY,
 * FITNESS FOR A PARTICULAR PURPOSE, TITLE, AND ANY WARRANTY OR CONDITION OF NON-INFRINGEMENT. IBM SHALL NOT BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR OPERATION OF THE SAMPLE SOURCE CODE.
 * IBM HAS NO OBLIGATION TO PROVIDE MAINTENANCE, SUPPORT, UPDATES, ENHANCEMENTS OR MODIFICATIONS TO THE SAMPLE SOURCE CODE.
 */
var feedsData = null, busy = null;

function wlCommonInit() {
    busy = new WL.BusyIndicator(null, {text : 'Loading...'}); 
	loadFeeds();
}

function loadFeeds() {
	busy.show();
	
	var invocationData = {
		adapter : 'StarterApplicationAdapter',
		procedure : 'getEngadgetFeeds',
		parameters : []
	};
	
	WL.Client.invokeProcedure(invocationData, {
		onSuccess : loadFeedsOK, 
		onFailure : loadFeedsFAIL
	});
}

function loadFeedsOK(data) {
	if (!data || !data.invocationResult || !data.invocationResult.items || data.invocationResult.items.length === 0) {
		Ext.Msg.alert(Messages.noFeedsError);
	}
	
	feedsData = data.invocationResult.items;
	loadPage();
}

function loadFeedsFAIL(data) {
	busy.hide();
	WL.SimpleDialog.show("Starter Application", "Service not available. Try again later.", 
		[{
			text : 'Reload',
			handler : WL.Client.reloadApp
		},
		{
			text: 'Close',
			handler : function() {}
		}]
	); 
}

function loadPage() {
	Ext.application({
		launch : function() {
			new Ext.TabPanel({
				fullscreen: true,
				tabBar : {
		            dock : 'top',
		            layout : { pack : 'center'},
		        },
				items: [
					{
						iconCls : 'favorites',
						title : Messages.tabFeed,
						xtype: 'list',
						itemTpl : '<div class="feedTitle">{title}</div><div class="pubDate">{pubDate}</div>',
						data : feedsData,
							onItemDisclosure : function(record, btn, index) {
								showFeed(record, btn, index);
							},
					},

					{
						iconCls : 'info',
						title : Messages.tabAbout,
						scrollable: {
						    direction: 'vertical',
						    directionLock: true,
						},
						html : '<div id="aboutTab"><h2 id="aboutMobileFirstTitle">' + Messages.aboutMobileFirstTitle + '</h2><p id="aboutMobileFirstProductName">' + Messages.aboutMobileFirstProductName + '</p><p id="aboutMobileFirstVersion">' + Messages.aboutMobileFirstVersion + '</p><p id="aboutMobileFirstText">' + Messages.aboutMobileFirstText + '</p><a id="aboutMobileFirstLink" href="https://www.ibm.com/developerworks/mobile/">' + Messages.aboutMobileFirstLink + '</a></div>',
					},
				]
			});
		}
	});

	var feed = new Ext.Panel({
		fullscreen : true,
		hidden : true,
		modal : true,
		scrollable: {
		    direction: 'vertical',
		    directionLock: true,
		},
		items:[
			{
				xtype: 'button',
				text: Messages.backToFeedList,
				ui: 'large',
				docked: 'top',
				floating : true,
				handler : function () {
					feed.hide();
				}
			}
		], 
	});

	var showFeed = function (record, btn, index) {
		feed.updateHtml('<div id="feedText">' + record.get('description') + '</div>');
		feed.show();
	};
	busy.hide();
}